@@ -419,6 +419,22 @@ impl Value {
             _ => false,
         }
     }
+    pub fn is_numeric(&self) -> bool {
+        match self {
+            Value::U8(_)
+            | Value::U16(_)
+            | Value::U32(_)
+            | Value::U64(_)
+            | Value::I8(_)
+            | Value::I16(_)
+            | Value::I32(_)
+            | Value::I64(_)
+            | Value::F32(_)
+            | Value::F64(_) => true,
+            Value::String(v) => v.parse::<f64>().is_ok() || v.parse::<u64>().is_ok(),
+            _ => false,
+        }
+    }
 }
 
 impl Eq for Value {}
